@@ -186,10 +186,11 @@ class CiPipelineHandlers:
             plugin_minimal_data = {}
 
             for plugin in plugin_metadata.get("parentPlugins", []):
-                for version in plugin.get("pluginVersions", {}).get("detailedPluginVersionData", []):
-                    (plugin_name, plugin_version) = (version.get("name", ""), version.get("pluginVersion", ""))
+                for version in plugin.get("pluginVersions", {}).get("minimalPluginVersionData", []):
+                    plugin_name = version.get("name", None)
+                    plugin_version = version.get("pluginVersion", None)
 
-                    if (plugin_name, plugin_version) != ("", ""):
+                    if plugin_name and plugin_version:
                         plugin_minimal_data[(plugin_name, plugin_version)] = version
 
             plugin_name = ""
@@ -250,22 +251,25 @@ class CiPipelineHandlers:
                         index += 1
                     else:
                         detailed_plugin_version_data = []
+                        input_vars = []
                         for plugin_data in applied_plugin_metadata:
 
                             step_name = step.get("name", "")
                             pattern = re.compile(rf"^{re.escape(step_name)}(\s+[vV]\d.*)?$")
                             plugin_name = plugin_data.get("name")
                             if pattern.match(plugin_name):
-                                detailed_plugin_version_data = plugin_data.get("pluginVersions", {}).get("detailedPluginVersionData", [])
+                                detailed_plugin_version_data = plugin_data.get("pluginVersions", {}).get("minimalPluginVersionData", [])
+                                input_vars = plugin_data.get("pluginVersions", {}).get("detailedPluginVersionData")[0].get("inputVariables")
                                 break
                             elif plugin_name == step_name:
-                                detailed_plugin_version_data = plugin_data.get("pluginVersions", {}).get("detailedPluginVersionData", [])
+                                detailed_plugin_version_data = plugin_data.get("pluginVersions", {}).get("minimalPluginVersionData", [])
+                                input_vars = plugin_data.get("pluginVersions", {}).get("detailedPluginVersionData")[0].get("inputVariables")
                                 break
                         if not detailed_plugin_version_data:
                             print(f"detailed_plugin_version_data not found for plugin: {step.get('name')}")
                             return current_steps
 
-                        add_plugin_result = CiPipelineHandlers.add_new_plugin(step, index, applied_plugin_metadata, detailed_plugin_version_data)
+                        add_plugin_result = CiPipelineHandlers.add_new_plugin(step, index, applied_plugin_metadata, detailed_plugin_version_data, input_vars)
                         if not add_plugin_result["success"]:
                             print(f"add_new_plugin failed: {add_plugin_result.get('error')}")
                             return current_steps
@@ -279,7 +283,7 @@ class CiPipelineHandlers:
             return current_steps
 
     @staticmethod
-    def add_new_plugin(step: dict, index: int, applied_plugin_metadata: list, detailed_plugin_version_data: list):
+    def add_new_plugin(step: dict, index: int, applied_plugin_metadata: list, detailed_plugin_version_data: list, input_vars):
 
 
         try:
@@ -291,9 +295,9 @@ class CiPipelineHandlers:
                     break
 
             input_variables = []
-            if plugin.get("inputVariables", []):
+            if input_vars:
 
-                for input_variable in plugin.get("inputVariables", []):
+                for input_variable in input_vars:
 
                     input_variables.append(InputVariable(
                         allow_empty_value=input_variable.get("allowEmptyValue", False),
